@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python3
 
 '''
 
@@ -843,7 +843,7 @@ def getSubAccounts(account):
 
     flat_accounts = []
 
-    if 'subaccounts' in account.keys():
+    if 'subaccounts' in list(account.keys()):
         for n, subaccount in enumerate(account['subaccounts']):
             flat_accounts.append(subaccount)
             flat_accounts = flat_accounts + getSubAccounts(subaccount)
@@ -1141,7 +1141,7 @@ def payBill(book, id, posted_account_guid, transfer_account_guid, payment_date,
 
     xfer_acc = account_guid.AccountLookup(session.book)
 
-    # We pay the negitive total as the bill as this seemed to cause issues
+    # We pay the negative total as the bill as this seemed to cause issues
     # with the split not being set correctly and not being marked as paid
     bill.ApplyPayment(None, xfer_acc, bill.GetTotal().neg(), GncNumeric(0),
         datetime.datetime.strptime(payment_date, '%Y-%m-%d'), memo, num)
@@ -1824,7 +1824,7 @@ def gnc_numeric_from_decimal(decimal_value):
     numerator_place_value = 1
     # add each digit to the final value multiplied by the place value
     # from least significant to most sigificant
-    for i in xrange(len(digits)-1,-1,-1):
+    for i in range(len(digits)-1,-1,-1):
         numerator += digits[i] * numerator_place_value
         numerator_place_value *= TEN
 
