@@ -389,6 +389,7 @@ gnc_tree_util_split_reg_template_get_transfer_entry (Split *split)
 		      "sx-account", &guid,
 		      NULL);
     account = xaccAccountLookup (guid, gnc_get_current_book ());
+    guid_free (guid);
     name = account ? gnc_get_account_name_for_register (account) : NULL;
 
     return name;
@@ -1081,7 +1082,6 @@ gnc_tree_util_set_number_for_input (GncTreeViewSplitReg *view, Transaction *tran
         if (gnc_numeric_zero_p (value))
         {
             amount = gnc_numeric_create (1,1);
-            value = gnc_numeric_mul (input, amount, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND);
             xaccSplitSetValue (split, input);
             xaccSplitSetAmount (split, amount);
             LEAVE("");
