@@ -87,7 +87,7 @@ typedef struct GncTreeViewOwnerPrivate
 } GncTreeViewOwnerPrivate;
 
 #define GNC_TREE_VIEW_OWNER_GET_PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_TREE_VIEW_OWNER, GncTreeViewOwnerPrivate))
+   ((GncTreeViewOwnerPrivate*)g_type_instance_get_private((GTypeInstance*)o, GNC_TYPE_TREE_VIEW_OWNER))
 
 
 /************************************************************/
@@ -96,33 +96,7 @@ typedef struct GncTreeViewOwnerPrivate
 
 static GObjectClass *parent_class = NULL;
 
-GType
-gnc_tree_view_owner_get_type (void)
-{
-    static GType gnc_tree_view_owner_type = 0;
-
-    if (gnc_tree_view_owner_type == 0)
-    {
-        static const GTypeInfo our_info =
-        {
-            sizeof (GncTreeViewOwnerClass),
-            NULL,
-            NULL,
-            (GClassInitFunc) gnc_tree_view_owner_class_init,
-            NULL,
-            NULL,
-            sizeof (GncTreeViewOwner),
-            0,
-            (GInstanceInitFunc) gnc_tree_view_owner_init
-        };
-
-        gnc_tree_view_owner_type = g_type_register_static (
-                                       GNC_TYPE_TREE_VIEW, GNC_TREE_VIEW_OWNER_NAME,
-                                       &our_info, 0);
-    }
-
-    return gnc_tree_view_owner_type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(GncTreeViewOwner, gnc_tree_view_owner, GNC_TYPE_TREE_VIEW)
 
 static void
 gnc_tree_view_owner_class_init (GncTreeViewOwnerClass *klass)
@@ -135,8 +109,6 @@ gnc_tree_view_owner_class_init (GncTreeViewOwnerClass *klass)
     o_class = G_OBJECT_CLASS (klass);
     o_class->finalize = gnc_tree_view_owner_finalize;
 
-    g_type_class_add_private(klass, sizeof(GncTreeViewOwnerPrivate));
-
     gnc_hook_add_dangler(HOOK_CURRENCY_CHANGED,
                          (GFunc)gtvo_currency_changed_cb, NULL);
 }
@@ -504,9 +476,7 @@ gnc_tree_view_owner_new (GncOwnerType owner_type)
                                         GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                         sort_by_string);
     gnc_tree_view_add_toggle_column (view, _("Active"),
-                                     /* Translators: This string has a context prefix; the translation
-                                        must only contain the part after the | character. */
-                                     Q_("Column letter for 'Active'|A"),
+                                     C_("Column letter for 'Active'", "A"),
                                      GNC_OWNER_TREE_ACTIVE_COL,
                                      GNC_TREE_MODEL_OWNER_COL_ACTIVE,
                                      GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
