@@ -378,8 +378,8 @@ gnc_stock_split_assistant_finish (GtkAssistant *assistant,
     xaccSplitMakeStockSplit (split);
     /* Set split-action with gnc_set_num_action which is the same as
      * xaccSplitSetAction with these arguments */
-    /* Translators: This string has a disambiguation prefix */
-    gnc_set_num_action (NULL, split, NULL, Q_("Action Column|Split"));
+
+    gnc_set_num_action (NULL, split, NULL, C_("Action Column", "Split"));
 
     amount = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT (info->price_edit));
     if (gnc_numeric_positive_p (amount))
