@@ -1353,11 +1353,11 @@ gsr_default_associate_handler_location (GNCSplitReg *gsr, Transaction *trans, gb
     // add a label and set entry text if required
     if (have_uri)
     {
-        label = gtk_label_new (_("Amend URL:"));
+        label = gtk_label_new (_("Amend URL"));
         gtk_entry_set_text (GTK_ENTRY (entry), xaccTransGetAssociation (trans));
     }
     else
-        label = gtk_label_new (_("Enter URL like https://www.gnucash.org:"));
+        label = gtk_label_new (_("Enter URL like https://www.gnucash.org"));
 
     // pack label and entry to content area
     gnc_label_set_alignment (label, 0.0, 0.5);
@@ -2353,15 +2353,21 @@ gnc_split_reg_enter( GNCSplitReg *gsr, gboolean next_transaction )
             }
         }
     }
-
     /* First record the transaction. This will perform a refresh. */
     if (!gnc_split_reg_record (gsr))
     {
-        /* make sure the sheet has the focus if the record is FALSE
+        /* we may come here from the transfer cell if we decline to create a
+         * new account, make sure the sheet has the focus if the record is FALSE
          * which results in no cursor movement. */
         gnc_split_reg_focus_on_sheet (gsr);
-        LEAVE(" ");
-        return;
+
+        /* if there are no changes, just enter was pressed, proceed to move
+         * other wise lets not move. */
+        if (gnc_table_current_cursor_changed (sr->table, FALSE))
+        {
+            LEAVE(" ");
+            return;
+        }
     }
 
     if (!goto_blank && next_transaction)
@@ -2476,7 +2482,7 @@ gsr_create_summary_bar( GNCSplitReg *gsr )
 
     gsr->filter_label = add_summary_label (summarybar, FALSE, "", NULL);
     gsr->sort_arrow = gtk_image_new_from_icon_name ("image-missing", GTK_ICON_SIZE_SMALL_TOOLBAR);
-    gsr->sort_label = add_summary_label (summarybar, FALSE, _("Sort By: "), gsr->sort_arrow);
+    gsr->sort_label = add_summary_label (summarybar, FALSE, _("Sort By:"), gsr->sort_arrow);
 
     gnc_widget_style_context_add_class (GTK_WIDGET(gsr->filter_label), "gnc-class-highlight");
     gnc_widget_style_context_add_class (GTK_WIDGET(gsr->sort_arrow), "gnc-class-highlight");
