@@ -1145,7 +1145,7 @@ gnc_reconcile_window_create_view_box (Account *account,
     gtk_box_set_homogeneous (GTK_BOX (hbox), FALSE);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new (_("Total:"));
+    label = gtk_label_new (_("Total"));
     gnc_label_set_alignment (label, 1.0, 0.5);
     gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
@@ -1826,7 +1826,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
             gtk_box_pack_start (GTK_BOX (totals_hbox), value_vbox, TRUE, TRUE, 0);
 
             /* statement date title/value */
-            title = gtk_label_new (_("Statement Date:"));
+            title = gtk_label_new (_("Statement Date"));
             gnc_label_set_alignment (title, 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (title_vbox), title, FALSE, FALSE, 0);
 
@@ -1836,7 +1836,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
             gtk_box_pack_start (GTK_BOX (value_vbox), value, FALSE, FALSE, 0);
 
             /* starting balance title/value */
-            title = gtk_label_new(_("Starting Balance:"));
+            title = gtk_label_new(_("Starting Balance"));
             gnc_label_set_alignment (title, 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (title_vbox), title, FALSE, FALSE, 3);
 
@@ -1846,7 +1846,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
             gtk_box_pack_start (GTK_BOX (value_vbox), value, FALSE, FALSE, 3);
 
             /* ending balance title/value */
-            title = gtk_label_new (_("Ending Balance:"));
+            title = gtk_label_new (_("Ending Balance"));
             gnc_label_set_alignment (title, 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (title_vbox), title, FALSE, FALSE, 0);
 
@@ -1856,7 +1856,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
             gtk_box_pack_start (GTK_BOX (value_vbox), value, FALSE, FALSE, 0);
 
             /* reconciled balance title/value */
-            title = gtk_label_new (_("Reconciled Balance:"));
+            title = gtk_label_new (_("Reconciled Balance"));
             gnc_label_set_alignment (title, 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (title_vbox), title, FALSE, FALSE, 0);
 
@@ -1866,7 +1866,7 @@ recnWindow2WithBalance (GtkWidget *parent, Account *account,
             gtk_box_pack_start (GTK_BOX (value_vbox), value, FALSE, FALSE, 0);
 
             /* difference title/value */
-            title = gtk_label_new (_("Difference:"));
+            title = gtk_label_new (_("Difference"));
             gnc_label_set_alignment (title, 1.0, 0.5);
             gtk_box_pack_start (GTK_BOX (title_vbox), title, FALSE, FALSE, 0);
 
