@@ -55,14 +55,22 @@
 #include "gnc-session.h"
 #include "engine-helpers-guile.h"
 #include "swig-runtime.h"
+#include "guile-mappings.h"
+#ifdef __MINGW32__
+#include <Windows.h>
+#include <fcntl.h>
+#endif
 
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = GNC_MOD_GUI;
 
-#ifdef HAVE_GETTEXT
-#  include <libintl.h>
-#  include <locale.h>
-#endif
+/* Change the following to have a console window attached to GnuCash
+ * for displaying stdout and stderr on Windows.
+ */
+#define __MSWIN_CONSOLE__ 0
+
+#include <libintl.h>
+#include <locale.h>
 
 #ifdef MAC_INTEGRATION
 #  include <Foundation/Foundation.h>
@@ -92,6 +100,7 @@ static const char  *add_quotes_file  = NULL;
 static char        *namespace_regexp = NULL;
 static const char  *file_to_load     = NULL;
 static gchar      **args_remaining   = NULL;
+static gchar       *sys_locale       = NULL;
 
 static GOptionEntry options[] =
 {
@@ -441,27 +450,14 @@ gnc_parse_command_line(int *argc, char ***argv)
     g_option_context_free (context);
     if (gnucash_show_version)
     {
-        gchar *vcs;
-
+        const char *format_string;
         if (is_development_version)
-            g_print (_("GnuCash %s development version"), VERSION);
+            format_string = _("GnuCash %s development version");
         else
-            g_print (_("GnuCash %s"), VERSION);
+            format_string = _("GnuCash %s");
 
-#ifdef GNC_VCS
-        vcs = GNC_VCS " ";
-#else
-        vcs = "";
-#endif
-
-        /* Allow builder to override the build id (eg distributions may want to
-         * print an package source version number (rpm, dpkg,...) instead of our git ref */
-        if (g_strcmp0("", GNUCASH_BUILD_ID) != 0)
-            g_print ("\n%s: %s\n",
-                     _("Build ID"), GNUCASH_BUILD_ID);
-        else
-            g_print ("\n%s: %s%s (%s)\n",
-                     _("Build ID"), vcs, GNC_VCS_REV, GNC_VCS_REV_DATE);
+        g_print (format_string, gnc_version());
+        g_print ("\n%s: %s\n", _("Build ID"), gnc_build_id());
         exit(0);
     }
 
@@ -754,10 +750,103 @@ gnc_log_init()
     }
 }
 
+#ifdef __MINGW32__
+/* If one of the Unix locale variables LC_ALL, LC_MESSAGES, or LANG is
+ * set in the environment check to see if it's a valid locale and if
+ * it is set both the Windows and POSIX locales to that. If not
+ * retrieve the Windows locale and set POSIX to match.
+ */
+static void
+set_win32_thread_locale()
+{
+    WCHAR lpLocaleName[LOCALE_NAME_MAX_LENGTH];
+    char *locale = NULL;
+
+    if (((locale = getenv ("LC_ALL")) != NULL && locale[0] != '\0') ||
+      ((locale = getenv ("LC_MESSAGES")) != NULL && locale[0] != '\0') ||
+      ((locale = getenv ("LANG")) != NULL && locale[0] != '\0'))
+    {
+	gunichar2* wlocale = NULL;
+	int len = 0;
+	len = strchr(locale, '.') - locale;
+	locale[2] = '-';
+	wlocale = g_utf8_to_utf16 (locale, len, NULL, NULL, NULL);
+	if (IsValidLocaleName(wlocale))
+	{
+	    LCID lcid = LocaleNameToLCID(wlocale, LOCALE_ALLOW_NEUTRAL_NAMES);
+	    SetThreadLocale(lcid);
+	    locale[2] = '_';
+	    setlocale (LC_ALL, locale);
+	    sys_locale = locale;
+	    g_free(wlocale);
+	    return;
+	}
+	g_free(locale);
+	g_free(wlocale);
+    }
+    if (GetUserDefaultLocaleName(lpLocaleName, LOCALE_NAME_MAX_LENGTH))
+    {
+	sys_locale = g_utf16_to_utf8((gunichar2*)lpLocaleName,
+				     LOCALE_NAME_MAX_LENGTH,
+				     NULL, NULL, NULL);
+	sys_locale[2] = '_';
+	setlocale (LC_ALL, sys_locale);
+	return;
+    }
+}
+#endif
+
+/* Creates a console window on MSWindows to display stdout and stderr
+ * when __MSWIN_CONSOLE__ is defined at the top of the file.
+ *
+ * Useful for displaying the diagnostics printed before logging is
+ * started and if logging is redirected with --logto=stderr.
+ */
+static void
+redirect_stdout (void)
+{
+#if defined __MINGW32__ && __MSWIN_CONSOLE__
+    static const WORD MAX_CONSOLE_LINES = 500;
+   int hConHandle;
+    long lStdHandle;
+    CONSOLE_SCREEN_BUFFER_INFO coninfo;
+    FILE *fp;
+
+    // allocate a console for this app
+    AllocConsole();
+
+    // set the screen buffer to be big enough to let us scroll text
+    GetConsoleScreenBufferInfo(GetStdHandle(STD_OUTPUT_HANDLE), &coninfo);
+    coninfo.dwSize.Y = MAX_CONSOLE_LINES;
+    SetConsoleScreenBufferSize(GetStdHandle(STD_OUTPUT_HANDLE), coninfo.dwSize);
+
+    // redirect unbuffered STDOUT to the console
+    lStdHandle = (long)GetStdHandle(STD_OUTPUT_HANDLE);
+    hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
+    fp = _fdopen( hConHandle, "w" );
+    *stdout = *fp;
+    setvbuf( stdout, NULL, _IONBF, 0 );
+
+    // redirect unbuffered STDIN to the console
+    lStdHandle = (long)GetStdHandle(STD_INPUT_HANDLE);
+    hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
+    fp = _fdopen( hConHandle, "r" );
+    *stdin = *fp;
+    setvbuf( stdin, NULL, _IONBF, 0 );
+
+    // redirect unbuffered STDERR to the console
+    lStdHandle = (long)GetStdHandle(STD_ERROR_HANDLE);
+    hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
+    fp = _fdopen( hConHandle, "w" );
+    *stderr = *fp;
+    setvbuf( stderr, NULL, _IONBF, 0 );
+#endif
+}
+
 int
 main(int argc, char ** argv)
 {
-    gchar *sys_locale = NULL;
+    gchar *localedir = gnc_path_get_localedir();
 #if !defined(G_THREADS_ENABLED) || defined(G_THREADS_IMPL_NONE)
 #    error "No GLib thread implementation available!"
 #endif
@@ -771,6 +860,7 @@ main(int argc, char ** argv)
         }
     }
 #endif
+    redirect_stdout ();
 
     /* This should be called before gettext is initialized
      * The user may have configured a different language via
@@ -778,9 +868,11 @@ main(int argc, char ** argv)
      */
 #ifdef MAC_INTEGRATION
     set_mac_locale();
+#elif defined __MINGW32__
+    set_win32_thread_locale();
 #endif
     gnc_environment_setup();
-#ifndef MAC_INTEGRATION /* setlocale already done */
+#if ! defined MAC_INTEGRATION && ! defined __MINGW32__/* setlocale already done */
     sys_locale = g_strdup (setlocale (LC_ALL, ""));
     if (!sys_locale)
       {
@@ -790,17 +882,12 @@ main(int argc, char ** argv)
         setlocale (LC_ALL, "C");
       }
 #endif
-#ifdef HAVE_GETTEXT
-    {
-        gchar *localedir = gnc_path_get_localedir();
-        bindtextdomain(GETTEXT_PACKAGE, localedir);
-	bindtextdomain("iso_4217", localedir); // For win32 to find currency name translations
-	bind_textdomain_codeset("iso_4217", "UTF-8");
-	textdomain(GETTEXT_PACKAGE);
-        bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-        g_free(localedir);
-    }
-#endif
+    bindtextdomain(GETTEXT_PACKAGE, localedir);
+    bindtextdomain("iso_4217", localedir); // For win32 to find currency name translations
+    bind_textdomain_codeset("iso_4217", "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    g_free(localedir);
 
     gnc_parse_command_line(&argc, &argv);
     gnc_print_unstable_message();
@@ -814,14 +901,11 @@ main(int argc, char ** argv)
 
     gnc_log_init();
 
-#ifndef MAC_INTEGRATION
-    /* Write some locale details to the log to simplify debugging
-     * To be on the safe side, only do this if not on OS X,
-     * to avoid unintentionally messing up the locale settings */
+    /* Write some locale details to the log to simplify debugging */
     PINFO ("System locale returned %s", sys_locale ? sys_locale : "(null)");
-    PINFO ("Effective locale set to %s.", setlocale (LC_ALL, ""));
+    PINFO ("Effective locale set to %s.", setlocale (LC_ALL, NULL));
     g_free (sys_locale);
-#endif
+    sys_locale = NULL;
 
     /* If asked via a command line parameter, fetch quotes only */
     if (add_quotes_file)
