@@ -44,15 +44,9 @@
 
 #include "gnc-ab-utils.h"
 
-#ifdef AQBANKING_VERSION_5_PLUS
 # include <gwenhywfar/syncio_file.h>
 # include <gwenhywfar/syncio_buffered.h>
 typedef GWEN_SYNCIO GWEN_IO_LAYER;
-#else
-# include <gwenhywfar/io_file.h>
-# include <gwenhywfar/io_buffered.h>
-# include <gwenhywfar/iomanager.h>
-#endif
 
 #include "dialog-ab-trans.h"
 #include "dialog-utils.h"
@@ -79,16 +73,18 @@ gnc_file_aqbanking_import(GtkWindow *parent,
     AB_BANKING *api = NULL;
     gboolean online = FALSE;
     GncGWENGui *gui = NULL;
+#ifndef AQBANKING6
     AB_IMEXPORTER *importer;
+#endif
     GWEN_DB_NODE *db_profiles = NULL;
     GWEN_DB_NODE *db_profile;
     AB_IMEXPORTER_CONTEXT *context = NULL;
     GWEN_IO_LAYER *io = NULL;
     GncABImExContextImport *ieci = NULL;
-    AB_JOB_LIST2 *job_list = NULL;
-    AB_JOB_LIST2_ITERATOR *jit;
-    AB_JOB *job;
-    AB_JOB_STATUS job_status;
+    GNC_AB_JOB_LIST2 *job_list = NULL;
+    GNC_AB_JOB_LIST2_ITERATOR *jit;
+    GNC_AB_JOB *job;
+    GNC_AB_JOB_STATUS job_status;
     gboolean successful = TRUE;
     int num_jobs = 0;
     int num_jobs_failed = 0;
@@ -111,13 +107,14 @@ gnc_file_aqbanking_import(GtkWindow *parent,
     gnc_set_default_directory(GNC_PREFS_GROUP_AQBANKING, default_dir);
     g_free(default_dir);
 
+#ifndef AQBANKING6
     dtaus_fd = g_open(selected_filename, O_RDONLY, 0);
     if (dtaus_fd == -1)
     {
         DEBUG("Could not open file %s", selected_filename);
         goto cleanup;
     }
-
+#endif
     /* Get the API */
     api = gnc_AB_BANKING_new();
     if (!api)
@@ -125,11 +122,8 @@ gnc_file_aqbanking_import(GtkWindow *parent,
         g_warning("gnc_file_aqbanking_import: Couldn't get AqBanking API");
         goto cleanup;
     }
-    if (AB_Banking_OnlineInit(api
-#ifdef AQBANKING_VERSION_4_EXACTLY
-                              , 0
-#endif
-                             ) != 0)
+#ifndef AQBANKING6
+    if (AB_Banking_OnlineInit(api) != 0)
     {
         g_warning("gnc_file_aqbanking_import: "
                   "Couldn't initialize AqBanking API");
@@ -176,12 +170,21 @@ gnc_file_aqbanking_import(GtkWindow *parent,
         }
         goto cleanup;
     }
+#endif
 
     /* Create a context to store the results */
     context = AB_ImExporterContext_new();
 
+#ifdef AQBANKING6
+    if (AB_Banking_ImportFromFileLoadProfile(api, aqbanking_importername,
+                                             context, aqbanking_profilename,
+                                             NULL, selected_filename) < 0)
+    {
+        g_warning("gnc_file_aqbanking_import: Error on import");
+        goto cleanup;
+    }
+#else
     /* Wrap file in buffered gwen io */
-#ifdef AQBANKING_VERSION_5_PLUS
     close(dtaus_fd);
     io = GWEN_SyncIo_File_new(selected_filename, GWEN_SyncIo_File_CreationMode_OpenExisting);
     g_assert(io);
@@ -197,35 +200,19 @@ gnc_file_aqbanking_import(GtkWindow *parent,
         }
         g_assert(GWEN_SyncIo_GetStatus(io) == GWEN_SyncIo_Status_Connected);
     }
-#else
-    io = GWEN_Io_LayerFile_new(dtaus_fd, -1);
-    g_assert(io);
-    if (GWEN_Io_Manager_RegisterLayer(io))
-    {
-        g_warning("gnc_file_aqbanking_import: Failed to wrap file");
-        goto cleanup;
-    }
-#endif
     dtaus_fd = -1;
 
     /* Run the import */
-    if (AB_ImExporter_Import(importer, context, io, db_profile
-#ifndef AQBANKING_VERSION_5_PLUS
-                             , 0
-#endif
-                            ))
+    if (AB_ImExporter_Import(importer, context, io, db_profile))
     {
         g_warning("gnc_file_aqbanking_import: Error on import");
         goto cleanup;
     }
 
     /* Close the file */
-#ifdef AQBANKING_VERSION_5_PLUS
     GWEN_SyncIo_free(io);
-#else
-    GWEN_Io_Layer_free(io);
-#endif
     io = NULL;
+#endif
 
     /* Before importing the results, if this is a new book, let user specify
      * book options, since they affect how transactions are created */
@@ -259,49 +246,69 @@ gnc_file_aqbanking_import(GtkWindow *parent,
             }
 
             /* And execute the jobs */
-            AB_Banking_ExecuteJobs(api, job_list, execution_context
-#ifndef AQBANKING_VERSION_5_PLUS
-                                   , 0
+#ifdef AQBANKING6
+            AB_Banking_SendCommands(api, job_list, execution_context);
+#else
+            AB_Banking_ExecuteJobs(api, job_list, execution_context);
 #endif
-                                  );
-
             /* Ignore the return value of AB_Banking_ExecuteJobs(), as the job's
              * status always describes better whether the job was actually
              * transferred to and accepted by the bank.  See also
-             * http://lists.gnucash.org/pipermail/gnucash-de/2008-September/006389.html
+             * https://lists.gnucash.org/pipermail/gnucash-de/2008-September/006389.html
              */
 
             /* So we must go through all jobs and check AB_Job_GetStatus(job)
              * to give the appropriate feedback if any of the jobs didn't
              * work. */
 
+#ifdef AQBANKING6
+            jit = AB_Transaction_List2_First(job_list);
+#else
             jit = AB_Job_List2_First(job_list);
+#endif
             if (jit)
             {
-
+#ifdef AQBANKING6
+                job = AB_Transaction_List2Iterator_Data(jit);
+#else
                 job = AB_Job_List2Iterator_Data(jit);
+#endif
                 while (job)
                 {
                     num_jobs += 1;
+#ifdef AQBANKING6
+                    job_status = AB_Transaction_GetStatus(job);
+                    if (job_status != AB_Transaction_StatusAccepted &&
+                        job_status != AB_Transaction_StatusPending)
+#else
                     job_status = AB_Job_GetStatus(job);
-                    if (job_status != AB_Job_StatusFinished
-                            && job_status != AB_Job_StatusPending)
+                    if (job_status != AB_Job_StatusFinished &&
+                        job_status != AB_Job_StatusPending)
+#endif
                     {
                         successful = FALSE;
                         num_jobs_failed += 1;
 
                         if (num_jobs_failed <= max_failures)
                         {
+#ifdef AQBANKING6
+                            gchar *fmt_str =_("Job %d status %d - %s\n");
+#else
+                            gchar *fmt_str =_("Job %d status %d - %s: %s\n");
+#endif
                             if (num_jobs_failed == 1)
                             {
                                 errstr = g_string_new("Failed jobs:\n");
                             }
-                            g_string_append_printf(errstr, _("Job %d status %d - %s: %s \n")
-                                                   , num_jobs
-                                                   , job_status
-                                                   , AB_Job_Status2Char(job_status)
-                                                   , AB_Job_GetResultText(job));
-                        }
+                            g_string_append_printf(errstr, fmt_str, num_jobs,
+                                                   job_status,
+#ifdef AQBANKING6
+                                                   AB_Transaction_Status_toString(job_status));
+#else
+                                                   AB_Job_Status2Char(job_status),
+                                                   AB_Job_GetResultText(job));
+#endif
+                   }
                         else
                         {
                             if (num_jobs_failed == (max_failures + 1) )
@@ -311,10 +318,17 @@ gnc_file_aqbanking_import(GtkWindow *parent,
                             }
                         }
                     }
+#ifdef AQBANKING6
+                    job = AB_Transaction_List2Iterator_Next(jit);
+#else
                     job = AB_Job_List2Iterator_Next(jit);
+#endif
                 } /* while */
-
+#ifdef AQBANKING6
+                AB_Transaction_List2Iterator_free(jit);
+#else
                 AB_Job_List2Iterator_free(jit);
+#endif
             }
 
             if (!successful)
@@ -349,38 +363,30 @@ gnc_file_aqbanking_import(GtkWindow *parent,
     }
 
 cleanup:
-    if (io)
-    {
-#ifdef AQBANKING_VERSION_5_PLUS
-        GWEN_SyncIo_free(io);
-#else
-        GWEN_Io_Layer_free(io);
-#endif
-    }
-
     if (job_list)
+#ifdef AQBANKING6
+        AB_Transaction_List2_freeAll(job_list);
+#else
         AB_Job_List2_FreeAll(job_list);
+    if (io)
+        GWEN_SyncIo_free(io);
+    if (db_profiles)
+        GWEN_DB_Group_free(db_profiles);
+    if (online)
+        AB_Banking_OnlineFini(api);
+    if (dtaus_fd != -1)
+        close(dtaus_fd);
+#endif
     if (ieci)
         g_free(ieci);
     if (context)
         AB_ImExporterContext_free(context);
-    if (db_profiles)
-        GWEN_DB_Group_free(db_profiles);
     if (gui)
         gnc_GWEN_Gui_release(gui);
-    if (online)
-#ifdef AQBANKING_VERSION_4_EXACTLY
-        AB_Banking_OnlineFini(api, 0);
-#else
-        AB_Banking_OnlineFini(api);
-#endif
     if (api)
         gnc_AB_BANKING_fini(api);
-    if (dtaus_fd != -1)
-        close(dtaus_fd);
     if (selected_filename)
         g_free(selected_filename);
     if (errstr)
         g_string_free(errstr, TRUE);
-
 }
