@@ -73,29 +73,31 @@ void csv_export_show_range_cb (GtkRadioButton *button, gpointer user_data);
 void csv_export_start_date_cb (GtkWidget *radio, gpointer user_data);
 void csv_export_end_date_cb (GtkWidget *radio, gpointer user_data);
 
-void csv_export_file_chooser_confirm_cb (GtkWidget *button, CsvExportInfo *info);
+void csv_export_file_chooser_file_activated_cb (GtkFileChooser *chooser, CsvExportInfo *info);
+void csv_export_file_chooser_selection_changed_cb (GtkFileChooser *chooser, CsvExportInfo *info);
 
+/* Fixme: Can we simplify the work of translators by splitting in invariant and variant paragraphs? */
 static const gchar *finish_tree_string = N_(
             /* Translators: %s is the file name string. */
-            "The account tree will be exported to the file '%s' when you click 'Apply'.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "The account tree will be exported to the file '%s' when you click \"Apply\".\n\n"
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *finish_trans_string = N_(
             /* Translators: %s is the file name string and %u the number of accounts. */
-            "When you click 'Apply', the transactions will be exported to the file '%s' and"
+            "When you click \"Apply\", the transactions will be exported to the file '%s' and"
             " the number of accounts exported will be %u.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *finish_trans_search_gl_string = N_(
             /* Translators: %s is the file name string. */
-            "When you click 'Apply', the transactions will be exported to the file '%s'.\n\n"
-            "You can also verify your selections by clicking on 'Back' or 'Cancel' to Abort Export.\n");
+            "When you click \"Apply\", the transactions will be exported to the file '%s'.\n\n"
+            "You can also verify your selections by clicking on \"Back\" or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_tree_string = N_(
             "This assistant will help you export the Account Tree to a file\n"
             " with the separator specified below.\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_trans_string = N_(
             "This assistant will help you export the Transactions to a file\n"
@@ -104,8 +106,8 @@ static const gchar *start_trans_string = N_(
             " require further manipulation to get them in a format you can use.\n\n"
             "Each Transaction will appear once in the export and will be listed in"
             " the order the accounts were processed\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 static const gchar *start_trans_simple_string = N_(
             "This assistant will help you export the Transactions to a file\n"
@@ -116,78 +118,96 @@ static const gchar *start_trans_simple_string = N_(
             " were processed\n\n"
             "By selecting the simple layout, the output will be equivalent to a single"
             " row register view and as such some of the transfer detail could be lost.\n\n"
-            "Select the settings you require for the file and then click 'Forward' to proceed"
-            " or 'Cancel' to Abort Export.\n");
+            "Select the settings you require for the file and then click \"Next\" to proceed"
+            " or \"Cancel\" to abort the export.\n");
 
 
 /**************************************************
- * csv_export_file_chooser_confirm_cb
+ * csv_export_assistant_check_filename
  *
- * call back for ok button in file chooser widget
+ * check for a valid filename for GtkFileChooser callbacks
  **************************************************/
-void
-csv_export_file_chooser_confirm_cb (GtkWidget *button, CsvExportInfo *info)
+static gboolean
+csv_export_assistant_check_filename (GtkFileChooser *chooser,
+                                     CsvExportInfo *info)
 {
-    GtkAssistant *assistant = GTK_ASSISTANT(info->window);
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
+    gchar *file_name = gtk_file_chooser_get_filename (chooser);
 
-    gchar *file_name;
-
-    gtk_assistant_set_page_complete (assistant, page, FALSE);
-
-    file_name = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(info->file_chooser));
-
-    if (file_name)
-    {
-        if (g_file_test (file_name, G_FILE_TEST_EXISTS))
-        {
-            const char *format = _("The file %s already exists. "
-                                   "Are you sure you want to overwrite it?");
-
-            /* if user says cancel, we should break out */
-            if (!gnc_verify_dialog (GTK_WINDOW (assistant), FALSE, format, file_name))
-                return;
-        }
-
-        info->file_name = g_strdup (file_name);
-        gtk_assistant_set_page_complete (assistant, page, TRUE);
-    }
-
-    if (file_name)
+    /* Test for a valid filename and not a directory */
+    if (file_name && !g_file_test (file_name, G_FILE_TEST_IS_DIR))
     {
         gchar *filepath = gnc_uri_get_path (file_name);
         gchar *filedir = g_path_get_dirname (filepath);
+
+        g_free (info->file_name);
+        info->file_name = g_strdup (file_name);
+
+        g_free (info->starting_dir);
         info->starting_dir = g_strdup (filedir);
+
         g_free (filedir);
         g_free (filepath);
+        g_free (file_name);
+
+        DEBUG("file_name selected is %s", info->file_name);
+        DEBUG("starting directory is %s", info->starting_dir);
+        return TRUE;
     }
     g_free (file_name);
+    return FALSE;
+}
 
-    DEBUG("file_name selected is %s", info->file_name);
-    DEBUG("starting directory is %s", info->starting_dir);
 
-    /* Step to next page if page is complete */
-    if(gtk_assistant_get_page_complete (assistant, page))
-        gtk_assistant_set_current_page (assistant, num + 1);
+/**************************************************
+ * csv_export_file_chooser_file_activated_cb
+ *
+ * call back for GtkFileChooser file-activated signal
+ **************************************************/
+void
+csv_export_file_chooser_file_activated_cb (GtkFileChooser *chooser,
+                                           CsvExportInfo *info)
+{
+    GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
+    gtk_assistant_set_page_complete (assistant, info->file_page, FALSE);
+
+    /* Test for a valid filename and not a directory */
+    if (csv_export_assistant_check_filename (chooser, info))
+    {
+        gtk_assistant_set_page_complete (assistant, info->file_page, TRUE);
+        gtk_assistant_next_page (assistant);
+    }
+}
+
+
+/**************************************************
+ * csv_export_file_chooser_selection_changed_cb
+ *
+ * call back for GtkFileChooser widget
+ **************************************************/
+void
+csv_export_file_chooser_selection_changed_cb (GtkFileChooser *chooser,
+                                              CsvExportInfo *info)
+{
+    GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
+
+    /* Enable the "Next" button based on a valid filename */
+    gtk_assistant_set_page_complete (assistant, info->file_page,
+        csv_export_assistant_check_filename (chooser, info));
 }
 
 
 /*******************************************************
  * csv_export_sep_cb
  *
- * call back for type of separartor required
+ * call back for type of separator required
  *******************************************************/
 void
 csv_export_sep_cb (GtkWidget *radio, gpointer user_data)
 {
     CsvExportInfo *info = user_data;
+    GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
     const gchar *name;
 
-    GtkAssistant *assistant = GTK_ASSISTANT(info->window);
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
-
     if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(radio)))
     {
         LEAVE("1st callback of pair. Defer to 2nd callback.");
@@ -198,7 +218,7 @@ csv_export_sep_cb (GtkWidget *radio, gpointer user_data)
 
     gtk_widget_set_sensitive (info->custom_entry, FALSE);
     info->use_custom = FALSE;
-    gtk_assistant_set_page_complete (assistant, page, TRUE);
+    gtk_assistant_set_page_complete (assistant, info->start_page, TRUE);
 
     if (g_strcmp0 (name, "comma_radio") == 0)
         info->separator_str = ",";
@@ -212,7 +232,7 @@ csv_export_sep_cb (GtkWidget *radio, gpointer user_data)
         gtk_widget_set_sensitive (info->custom_entry, TRUE);
         info->use_custom = TRUE;
         if (gtk_entry_get_text_length (GTK_ENTRY(info->custom_entry)) == 0)
-            gtk_assistant_set_page_complete (assistant, page, FALSE);
+            gtk_assistant_set_page_complete (assistant, info->start_page, FALSE);
     }
 }
 
@@ -258,20 +278,16 @@ void
 csv_export_custom_entry_cb (GtkWidget *widget, gpointer user_data)
 {
     CsvExportInfo *info = user_data;
+    GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
     const gchar *custom_str;
 
-    GtkAssistant *assistant = GTK_ASSISTANT(info->window);
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
-
     custom_str = gtk_entry_get_text (GTK_ENTRY(info->custom_entry));
     info->separator_str = strdup (custom_str);
 
     if (info->use_custom == TRUE && gtk_entry_get_text_length (GTK_ENTRY(info->custom_entry)) == 0)
-
-        gtk_assistant_set_page_complete (assistant, page, FALSE);
+        gtk_assistant_set_page_complete (assistant, info->start_page, FALSE);
     else
-        gtk_assistant_set_page_complete (assistant, page, TRUE);
+        gtk_assistant_set_page_complete (assistant, info->start_page, TRUE);
 }
 
 
@@ -397,27 +413,43 @@ csv_export_account_changed_cb (GtkTreeSelection *selection,
                                gpointer user_data)
 {
     CsvExportInfo *info = user_data;
-    GtkAssistant *assistant = GTK_ASSISTANT(info->window);
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
-
+    GtkAssistant *assistant = GTK_ASSISTANT(info->assistant);
     GncTreeViewAccount *view;
 
     g_return_if_fail(GTK_IS_TREE_SELECTION(selection));
 
     info->csva.num_accounts = update_accounts_tree (info);
 
-    /* Enable the Forward Assistant Button if we have accounts */
+    /* Enable the "Next" Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
-        gtk_assistant_set_page_complete (assistant, page, TRUE);
+        gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
     else
-        gtk_assistant_set_page_complete (assistant, page, FALSE);
+        gtk_assistant_set_page_complete (assistant, info->account_page, FALSE);
 
     view = GNC_TREE_VIEW_ACCOUNT(info->csva.account_treeview);
     info->csva.account_list = gnc_tree_view_account_get_selected_accounts (view);
 }
 
 
+/*******************************************************
+ * csv_export_select_all_clicked_cb
+ *
+ * select all the accounts
+ *******************************************************/
+static void
+csv_export_select_all_clicked_cb (GtkWidget *widget, gpointer user_data)
+{
+    CsvExportInfo *info = user_data;
+    GtkTreeSelection *selection = gtk_tree_view_get_selection
+                                    (GTK_TREE_VIEW (info->csva.account_treeview));
+
+    gtk_tree_view_expand_all (GTK_TREE_VIEW (info->csva.account_treeview));
+    gtk_tree_selection_select_all (selection);
+
+    gtk_widget_grab_focus (info->csva.account_treeview);
+}
+
+
 /*******************************************************
  * csv_export_select_subaccounts_clicked_cb
  *
@@ -463,7 +495,7 @@ get_filter_times (CsvExportInfo *info)
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.start_date_today)))
             info->csvd.start_time = gnc_time64_get_today_start();
         else
-            info->csvd.start_time = 0;
+            info->csvd.start_time = info->csvd.earliest_time;
     }
 
     if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.end_date_choose)))
@@ -477,7 +509,7 @@ get_filter_times (CsvExportInfo *info)
         if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(info->csvd.end_date_today)))
             info->csvd.end_time = gnc_time64_get_today_end();
         else
-            info->csvd.end_time = gnc_time (NULL);
+            info->csvd.end_time = info->csvd.latest_time;
     }
 }
 
@@ -496,6 +528,15 @@ csv_export_show_range_cb (GtkRadioButton *button, gpointer user_data)
     g_return_if_fail (GTK_IS_RADIO_BUTTON(button));
 
     active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button));
+
+    if (!active)
+    {
+        info->csvd.start_time = info->csvd.earliest_time;
+        info->csvd.end_time = info->csvd.latest_time;
+    }
+    else
+        get_filter_times (info);
+
     gtk_widget_set_sensitive (info->csvd.table, active);
 }
 
@@ -569,22 +610,19 @@ csv_export_end_date_cb (GtkWidget *radio, gpointer user_data)
 
 
 /*******************************************************************
- * get_earliest_in_book
+ * get_earliest_and_latest_in_book
  *
- * Find the earliest date occurring in the book.  Do this by making
- * a query and sorting by date. Since the truncated sort returns
- * only the *last* search results, sort in decreasing order.
+ * Find the earliest and latest dates occurring in the book.
  *******************************************************************/
-static time64
-get_earliest_in_book (QofBook *book)
+static void
+get_earliest_and_latest_in_book (CsvExportInfo *info, QofBook *book)
 {
     QofQuery *q;
     GSList *p1, *p2;
     GList *res;
-    time64 earliest;
+    time64 etime, ltime;
 
     q = qof_query_create_for (GNC_ID_SPLIT);
-    qof_query_set_max_results (q, 1);
     qof_query_set_book (q, book);
 
     /* Sort by transaction date */
@@ -593,24 +631,24 @@ get_earliest_in_book (QofBook *book)
     p2 = g_slist_prepend (NULL, QUERY_DEFAULT_SORT);
     qof_query_set_sort_order (q, p1, p2, NULL);
 
-    /* Reverse the sort order */
-    qof_query_set_sort_increasing (q, FALSE, FALSE, FALSE);
-
-    /* Run the query, find the earliest transaction date */
+    /* Run the query, find the earliest and latest transaction dates */
     res = qof_query_run (q);
 
     if (res)
     {
-        earliest = xaccQueryGetEarliestDateFound (q);
+        etime = xaccQueryGetEarliestDateFound (q);
+        ltime = xaccQueryGetLatestDateFound (q);
     }
     else
     {
         /* If no results, we don't want to bomb totally */
-        earliest = gnc_time (0);
+        etime = gnc_time (0);
+        ltime = gnc_time (NULL);
     }
+    info->csvd.earliest_time = gnc_time64_get_day_start (etime);
+    info->csvd.latest_time = gnc_time64_get_day_end (ltime);
 
     qof_query_destroy (q);
-    return earliest;
 }
 
 
@@ -625,8 +663,6 @@ csv_export_assistant_start_page_prepare (GtkAssistant *assistant,
         gpointer user_data)
 {
     CsvExportInfo *info = user_data;
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
     /* Set Start page text */
     if (info->export_type == XML_EXPORT_TREE)
@@ -641,7 +677,7 @@ csv_export_assistant_start_page_prepare (GtkAssistant *assistant,
     }
 
     /* Enable the Assistant Buttons */
-    gtk_assistant_set_page_complete (assistant, page, TRUE);
+    gtk_assistant_set_page_complete (assistant, info->start_page, TRUE);
 }
 
 
@@ -650,14 +686,12 @@ csv_export_assistant_account_page_prepare (GtkAssistant *assistant,
         gpointer user_data)
 {
     CsvExportInfo *info = user_data;
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
-    /* Enable the Forward Assistant Button if we have accounts */
+    /* Enable the "Next" Assistant Button if we have accounts */
     if (info->csva.num_accounts > 0)
-        gtk_assistant_set_page_complete (assistant, page, TRUE);
+        gtk_assistant_set_page_complete (assistant, info->account_page, TRUE);
     else
-        gtk_assistant_set_page_complete (assistant, page, FALSE);
+        gtk_assistant_set_page_complete (assistant, info->account_page, FALSE);
 }
 
 
@@ -666,16 +700,14 @@ csv_export_assistant_file_page_prepare (GtkAssistant *assistant,
                                         gpointer user_data)
 {
     CsvExportInfo *info = user_data;
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
 
     /* Set the default directory */
     if (info->starting_dir)
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(info->file_chooser), info->starting_dir);
     gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER(info->file_chooser), "");
 
-    /* Disable the Forward Assistant Button */
-    gtk_assistant_set_page_complete (assistant, page, FALSE);
+    /* Disable the "Next" Assistant Button */
+    gtk_assistant_set_page_complete (assistant, info->file_page, FALSE);
 }
 
 
@@ -684,8 +716,6 @@ csv_export_assistant_finish_page_prepare (GtkAssistant *assistant,
         gpointer user_data)
 {
     CsvExportInfo *info = user_data;
-    gint num = gtk_assistant_get_current_page (assistant);
-    GtkWidget *page = gtk_assistant_get_nth_page (assistant, num);
     gchar *text;
 
     /* Set Finish page text */
@@ -701,8 +731,18 @@ csv_export_assistant_finish_page_prepare (GtkAssistant *assistant,
     gtk_label_set_text (GTK_LABEL(info->finish_label), text);
     g_free (text);
 
+    /* Test if the filename exists */
+    if (g_file_test (info->file_name, G_FILE_TEST_EXISTS))
+    {
+        const char *format = _("The file %s already exists. "
+                               "Are you sure you want to overwrite it?");
+
+        /* if user says cancel, we should go back a page */
+        if (!gnc_verify_dialog (GTK_WINDOW (assistant), FALSE, format, info->file_name))
+            gtk_assistant_previous_page (assistant);
+    }
     /* Enable the Assistant Buttons */
-    gtk_assistant_set_page_complete (assistant, page, TRUE);
+    gtk_assistant_set_page_complete (assistant, info->finish_label, TRUE);
 }
 
 
@@ -796,8 +836,8 @@ csv_export_close_handler (gpointer user_data)
     if (info->mid_sep)
         g_free (info->mid_sep);
 
-    gnc_save_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->window));
-    gtk_widget_destroy (info->window);
+    gnc_save_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->assistant));
+    gtk_widget_destroy (info->assistant);
 }
 
 /*******************************************************
@@ -807,19 +847,16 @@ static GtkWidget *
 csv_export_assistant_create (CsvExportInfo *info)
 {
     GtkBuilder *builder;
-    GtkWidget *window;
-    GtkWidget *box, *h_box;
+    GtkWidget *h_box;
     GtkWidget *button;
     GtkWidget *table, *hbox;
-    time64 start_time, end_time;
 
     builder = gtk_builder_new();
     gnc_builder_add_from_file  (builder , "assistant-csv-export.glade", "csv_export_assistant");
-    window = GTK_WIDGET(gtk_builder_get_object (builder, "csv_export_assistant"));
-    info->window = window;
+    info->assistant = GTK_WIDGET(gtk_builder_get_object (builder, "csv_export_assistant"));
 
     // Set the style context for this assistant so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(window), "GncAssistExport");
+    gnc_widget_set_style_context (GTK_WIDGET(info->assistant), "GncAssistExport");
 
     /* Load default settings */
     load_settings (info);
@@ -840,7 +877,7 @@ csv_export_assistant_create (CsvExportInfo *info)
         // Don't provide simple export layout for search registers and General Journal
         if ((info->export_type == XML_EXPORT_TREE) || (info->account == NULL))
             gtk_widget_destroy (chkbox);
-        gtk_assistant_remove_page (GTK_ASSISTANT(window), 1); //remove accounts page
+        gtk_assistant_remove_page (GTK_ASSISTANT(info->assistant), 1); //remove accounts page
     }
     else
     {
@@ -869,21 +906,25 @@ csv_export_assistant_create (CsvExportInfo *info)
         /* select subaccounts button */
         button = GTK_WIDGET(gtk_builder_get_object (builder, "select_subaccounts_button"));
         info->csva.select_button = button;
-
         g_signal_connect (G_OBJECT(button), "clicked",
                           G_CALLBACK(csv_export_select_subaccounts_clicked_cb), info);
+
+        button = GTK_WIDGET(gtk_builder_get_object (builder, "select_all_button"));
+        info->csva.select_button = button;
+        g_signal_connect (G_OBJECT(button), "clicked",
+                          G_CALLBACK(csv_export_select_all_clicked_cb), info);
+
         g_signal_connect (G_OBJECT(info->csva.account_treeview), "cursor_changed",
                           G_CALLBACK(csv_export_cursor_changed_cb), info);
 
         /* Set the date info */
         button = GTK_WIDGET(gtk_builder_get_object (builder, "show_range"));
 
-        /* Earliest and Latest in Book */
-        start_time = get_earliest_in_book (gnc_get_current_book());
-        end_time = gnc_time (NULL);
+        /* Get the Earliest and Latest dates in Book */
+        get_earliest_and_latest_in_book (info, gnc_get_current_book());
 
-        info->csvd.start_time = start_time;
-        info->csvd.end_time = end_time;
+        info->csvd.start_time = info->csvd.earliest_time;
+        info->csvd.end_time = info->csvd.latest_time;
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), FALSE);
 
         table = GTK_WIDGET(gtk_builder_get_object (builder, "select_range_table"));
@@ -900,7 +941,7 @@ csv_export_assistant_create (CsvExportInfo *info)
         hbox = GTK_WIDGET(gtk_builder_get_object (builder, "start_date_hbox"));
         gtk_box_pack_start (GTK_BOX(hbox), info->csvd.start_date, TRUE, TRUE, 0);
         gtk_widget_show (info->csvd.start_date);
-        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.start_date), start_time);
+        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.start_date), info->csvd.start_time);
         g_signal_connect (G_OBJECT(info->csvd.start_date), "date-changed",
                         G_CALLBACK(csv_export_date_changed_cb), info);
 
@@ -909,7 +950,7 @@ csv_export_assistant_create (CsvExportInfo *info)
         hbox = GTK_WIDGET(gtk_builder_get_object (builder, "end_date_hbox"));
         gtk_box_pack_start (GTK_BOX(hbox), info->csvd.end_date, TRUE, TRUE, 0);
         gtk_widget_show (info->csvd.end_date);
-        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.end_date), end_time);
+        gnc_date_edit_set_time (GNC_DATE_EDIT(info->csvd.end_date), info->csvd.end_time);
         g_signal_connect (G_OBJECT (info->csvd.end_date), "date-changed",
                         G_CALLBACK (csv_export_date_changed_cb), info);
 
@@ -921,18 +962,14 @@ csv_export_assistant_create (CsvExportInfo *info)
     /* File chooser Page */
     info->file_page = GTK_WIDGET(gtk_builder_get_object(builder, "file_page"));
     info->file_chooser = gtk_file_chooser_widget_new (GTK_FILE_CHOOSER_ACTION_SAVE);
-    button = gtk_button_new_with_mnemonic (_("_OK"));
-    gtk_widget_set_size_request (button, 100, -1);
-    gtk_widget_show (button);
-    h_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-    gtk_box_set_homogeneous (GTK_BOX (h_box), TRUE);
-    gtk_box_pack_start(GTK_BOX(h_box), button, FALSE, FALSE, 0);
-    gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER(info->file_chooser), h_box);
-    g_signal_connect (G_OBJECT(button), "clicked",
-                      G_CALLBACK(csv_export_file_chooser_confirm_cb), info);
 
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "file_page"));
-    gtk_box_pack_start (GTK_BOX (box), info->file_chooser, TRUE, TRUE, 6);
+    g_signal_connect (G_OBJECT(info->file_chooser), "selection-changed",
+                      G_CALLBACK(csv_export_file_chooser_selection_changed_cb), info);
+
+    g_signal_connect (G_OBJECT(info->file_chooser), "file-activated",
+                      G_CALLBACK(csv_export_file_chooser_file_activated_cb), info);
+
+    gtk_box_pack_start (GTK_BOX (info->file_page), info->file_chooser, TRUE, TRUE, 6);
     gtk_widget_show (info->file_chooser);
 
     /* Finish Page */
@@ -941,11 +978,11 @@ csv_export_assistant_create (CsvExportInfo *info)
     /* Summary Page */
     info->summary_label = GTK_WIDGET(gtk_builder_get_object (builder, "summary_page"));
 
-    g_signal_connect (G_OBJECT(window), "destroy",
+    g_signal_connect (G_OBJECT(info->assistant), "destroy",
                       G_CALLBACK(csv_export_assistant_destroy_cb), info);
 
     gnc_restore_window_size (GNC_PREFS_GROUP,
-                             GTK_WINDOW(info->window), gnc_ui_get_main_window(NULL));
+                             GTK_WINDOW(info->assistant), gnc_ui_get_main_window(NULL));
     if (gnc_prefs_get_bool (GNC_PREFS_GROUP_GENERAL, GNC_PREF_SAVE_GEOMETRY))
     {
         GObject *object = gtk_builder_get_object (builder, "paned");
@@ -954,7 +991,7 @@ csv_export_assistant_create (CsvExportInfo *info)
 
     gtk_builder_connect_signals (builder, info);
     g_object_unref (G_OBJECT(builder));
-    return window;
+    return info->assistant;
 }
 
 static void
@@ -976,8 +1013,8 @@ gnc_file_csv_export_internal (CsvExportType export_type, Query *q, Account *acc)
     gnc_register_gui_component (ASSISTANT_CSV_EXPORT_CM_CLASS,
                                 NULL, csv_export_close_handler,
                                 info);
-    gtk_widget_show_all (info->window);
-    gnc_window_adjust_for_screen (GTK_WINDOW(info->window));
+    gtk_widget_show_all (info->assistant);
+    gnc_window_adjust_for_screen (GTK_WINDOW(info->assistant));
 }
 
 
