@@ -639,8 +639,9 @@ void gnc_file_log_replay (GtkWindow *parent)
                     {
                         do
                         {
+                            read_retval = fgets(read_buf, sizeof(read_buf), log_file);
                             /*DEBUG("Chunk read: %s",read_retval);*/
-                            if (strncmp(record_start_str, read_buf, strlen(record_start_str)) == 0) /* If a record started */
+                            if (read_retval && strncmp(record_start_str, read_buf, strlen(record_start_str)) == 0) /* If a record started */
                             {
                                 process_trans_record(log_file);
                             }
