@@ -89,6 +89,8 @@
 (define optname-transaction-matcher (N_ "Transaction Filter"))
 (define optname-transaction-matcher-regex
   (N_ "Use regular expressions for transaction filter"))
+(define optname-transaction-matcher-exclude
+  (N_ "Transaction Filter excludes matched strings"))
 (define optname-reconcile-status (N_ "Reconcile Status"))
 (define optname-void-transactions (N_ "Void Transactions"))
 (define optname-closing-transactions (N_ "Closing transactions"))
@@ -604,6 +606,13 @@ enable full POSIX regular expressions capabilities. '#work|#family' will match b
 tags within description, notes or memo. ")
     #f))
 
+  (gnc:register-trep-option
+   (gnc:make-simple-boolean-option
+    pagename-filter optname-transaction-matcher-exclude
+    "i3"
+    (_ "If this option is selected, transactions matching filter are excluded.")
+    #f))
+
   (gnc:register-trep-option
    (gnc:make-multichoice-option
     pagename-filter optname-reconcile-status
@@ -1936,11 +1945,13 @@ be excluded from periodic reporting.")
 
   (let* ((document (gnc:make-html-document))
          (account-matcher (opt-val pagename-filter optname-account-matcher))
-         (account-matcher-regexp (and (opt-val pagename-filter
-                                               optname-account-matcher-regex)
-                                      (catch 'regular-expression-syntax
-                                        (lambda () (make-regexp account-matcher))
-                                        (const 'invalid-regex))))
+         (account-matcher-regexp
+          (and (opt-val pagename-filter optname-account-matcher-regex)
+               (if (defined? 'make-regexp)
+                   (catch 'regular-expression-syntax
+                     (lambda () (make-regexp account-matcher))
+                     (const 'invalid-account-regex))
+                   'no-guile-regex-support)))
          (c_account_0 (or custom-source-accounts
                           (opt-val gnc:pagename-accounts optname-accounts)))
          (c_account_1 (filter
@@ -1962,9 +1973,13 @@ be excluded from periodic reporting.")
          (transaction-matcher (opt-val pagename-filter optname-transaction-matcher))
          (transaction-matcher-regexp
           (and (opt-val pagename-filter optname-transaction-matcher-regex)
-               (catch 'regular-expression-syntax
-                 (lambda () (make-regexp transaction-matcher))
-                 (const 'invalid-regex))))
+               (if (defined? 'make-regexp)
+                   (catch 'regular-expression-syntax
+                     (lambda () (make-regexp transaction-matcher))
+                     (const 'invalid-transaction-regex))
+                   'no-guile-regex-support)))
+         (transaction-filter-exclude?
+          (opt-val pagename-filter optname-transaction-matcher-exclude))
          (reconcile-status-filter
           (keylist-get-info reconcile-status-list
                             (opt-val pagename-filter optname-reconcile-status)
@@ -2040,16 +2055,33 @@ be excluded from periodic reporting.")
     (define (date-comparator? X Y)
       (generic-less? X Y 'date 'none #t))
 
+    (define (transaction-filter-match split)
+      (or (match? (xaccTransGetDescription (xaccSplitGetParent split)))
+          (match? (xaccTransGetNotes (xaccSplitGetParent split)))
+          (match? (xaccSplitGetMemo split))))
+
     (cond
      ((or (null? c_account_1)
-          (eq? account-matcher-regexp 'invalid-regex)
-          (eq? transaction-matcher-regexp 'invalid-regex))
+          (symbol? account-matcher-regexp)
+          (symbol? transaction-matcher-regexp))
 
-      ;; error condition: no accounts specified or obtained after filtering
       (gnc:html-document-add-object!
        document
-       (gnc:html-make-no-account-warning
-        report-title (gnc:report-id report-obj)))
+       (cond
+        ((null? c_account_1)
+         (gnc:html-make-no-account-warning report-title (gnc:report-id report-obj)))
+
+        ((symbol? account-matcher-regexp)
+         (gnc:html-make-generic-warning
+          report-title (gnc:report-id report-obj)
+          (string-append (_ "Error") " " (symbol->string account-matcher-regexp))
+          ""))
+
+        ((symbol? transaction-matcher-regexp)
+         (gnc:html-make-generic-warning
+          report-title (gnc:report-id report-obj)
+          (string-append (_ "Error") " " (symbol->string transaction-matcher-regexp))
+          ""))))
 
       ;; if an empty-report-message is passed by a derived report to
       ;; the renderer, display it here.
@@ -2113,9 +2145,9 @@ be excluded from periodic reporting.")
                     ((include) (is-filter-member split c_account_2))
                     ((exclude) (not (is-filter-member split c_account_2))))
                   (or (string-null? transaction-matcher)
-                      (match? (xaccTransGetDescription trans))
-                      (match? (xaccTransGetNotes trans))
-                      (match? (xaccSplitGetMemo split)))
+                      (if transaction-filter-exclude?
+                          (not (transaction-filter-match split))
+                          (transaction-filter-match split)))
                   (or (not custom-split-filter)
                       (custom-split-filter split)))))
          splits))
@@ -2188,9 +2220,9 @@ be excluded from periodic reporting.")
               (if (list? csvlist)
                   (catch #t
                     (lambda ()
-                      (with-output-to-file filename
-                        (lambda ()
-                          (display (lists->csv (append infolist csvlist))))))
+                      (call-with-output-file filename
+                        (lambda (p)
+                          (display (lists->csv (append infolist csvlist)) p))))
                     (lambda (key . args)
                       ;; Translators: ~a error type, ~a filename, ~s error details
                       (let ((fmt (N_ "error ~a during csv output to ~a: ~s")))
