@@ -346,7 +346,7 @@ by preventing negative stock balances.<br/>")
 	   (not (gnc-numeric-zero-p b-value)))
       (let* ((current-value (sum-basis b-list GNC-DENOM-AUTO))
             (value-ratio (if (zero? current-value)
-                             (throw 'div/0 (format #f "spinoff of ~0,2f currency units" current-value))
+                             (throw 'div/0 (format #f "spinoff of ~,2f currency units" current-value))
                              (gnc-numeric-div (gnc-numeric-add b-value current-value GNC-DENOM-AUTO GNC-DENOM-REDUCE)
                                               current-value GNC-DENOM-AUTO GNC-DENOM-REDUCE))))
 
@@ -955,7 +955,7 @@ by preventing negative stock balances.<br/>")
                                              )
 					      (if (= 0.0 moneyinvalue)
 						  ""
-						  (format #f "~0,2f%" (* 100 (/ bothgainvalue moneyinvalue)))))
+						  (format #f "~,2f%" (* 100 (/ bothgainvalue moneyinvalue)))))
 					)
 					(gnc:make-html-table-header-cell/markup "number-cell" income)))
 	      (if (not (eq? handle-brokerage-fees 'ignore-brokerage))
@@ -969,7 +969,7 @@ by preventing negative stock balances.<br/>")
                                              )
 					      (if (= 0.0 moneyinvalue)
 						  ""
-						  (format #f "~0,2f%" (* 100 (/ totalreturnvalue moneyinvalue))))))
+						  (format #f "~,2f%" (* 100 (/ totalreturnvalue moneyinvalue))))))
 					 )
 			)
 
@@ -997,8 +997,9 @@ by preventing negative stock balances.<br/>")
   ;; The first thing we do is make local variables for all the specific
   ;; options in the set of options given to the function. This set will
   ;; be generated by the options generator above.
-  (let ((to-date     (gnc:date-option-absolute-time
-                      (get-option gnc:pagename-general "Date")))
+  (let ((to-date     (gnc:time64-end-day-time
+                      (gnc:date-option-absolute-time
+                       (get-option gnc:pagename-general "Date"))))
         (accounts    (get-option gnc:pagename-accounts "Accounts"))
         (currency    (get-option gnc:pagename-general "Report's currency"))
         (price-source (get-option gnc:pagename-general
@@ -1160,7 +1161,7 @@ by preventing negative stock balances.<br/>")
 				       )
 				  (if (= 0.0 totalinvalue)
 				      ""
-				      (format #f "~0,2f%" (* 100 (/ totalgainvalue totalinvalue))))))
+				      (format #f "~,2f%" (* 100 (/ totalgainvalue totalinvalue))))))
 			       (gnc:make-html-table-cell/markup
 				"total-number-cell" sum-total-income)))
 	  (if (not (eq? handle-brokerage-fees 'ignore-brokerage))
@@ -1179,7 +1180,7 @@ by preventing negative stock balances.<br/>")
 				 )
 				  (if (= 0.0 totalinvalue)
 				      ""
-				      (format #f "~0,2f%" (* 100 (/ totalreturnvalue totalinvalue))))))
+				      (format #f "~,2f%" (* 100 (/ totalreturnvalue totalinvalue))))))
 			       ))
 
 
