@@ -148,164 +148,121 @@
         (_ "Maximum") (_ "Minimum") (_ "Gain") 
         (_ "Loss") (_ "Profit") ))
 
-;; analyze-splits crunches a split list into a set of period
-;; summaries.  Each summary is a list of (start-date end-date
-;; avg-bal max-bal min-bal total-in total-out net) if multiple
-;; accounts are selected the balance is the sum for all.  Each
-;; balance in a foreign currency will be converted to a double in
-;; the report-currency by means of the monetary->double
-;; function. 
-(define (analyze-splits splits start-bal-double 
-                        start-date end-date interval monetary->double
-			internal)
-  (let ((interval-list 
-         (gnc:make-date-interval-list start-date end-date interval))
-        (data-rows '()))
-    
-    (define (output-row interval-start 
-                        interval-end 
-                        stats-accum 
-                        minmax-accum
-                        gain-loss-accum)
-      (set! data-rows
-            (cons 
-             (list (qof-print-date interval-start)
-                   (qof-print-date interval-end)
-                   (/ (stats-accum 'total #f)
-                      (- interval-end
-                         interval-start))
-                   (minmax-accum 'getmax #f)
-                   (minmax-accum 'getmin #f)
-                   (gain-loss-accum 'debits #f) 
-                   (gain-loss-accum 'credits #f)
-                   (- (gain-loss-accum 'debits #f)
-                      (gain-loss-accum 'credits #f)))
-             data-rows)))
-    
-    ;; Returns a double which is the split value, correctly
-    ;; exchanged to the current report-currency. We use the exchange
-    ;; rate at the 'date'.
-    (define (get-split-value split date)
-      (monetary->double
-       (gnc:make-gnc-monetary
-        (xaccAccountGetCommodity (xaccSplitGetAccount split))
-        (xaccSplitGetAmount split))
-       date))
-    
-    ;; calculate the statistics for one interval - returns a list 
-    ;;  containing the following: 
-    ;; min-max acculumator
-    ;; average-accumulator
-    ;; gain-loss accumulator
-    ;; final balance for this interval
-    ;; splits remaining to be processed.
-    
-    ;; note that it is assumed that every split in in the list
-    ;; has a date >= from 
 
-    (define (process-interval splits from to start-balance)
+(define (analyze-splits splits balances daily-dates interval-dates
+                        internal-included exchange-fn report-currency)
+  ;; this is a tight loop. start with: daily-balances & daily-dates,
+  ;; interval-dates, and the splitlist. traverse the daily balances
+  ;; and splitlist until we cross an interval date boundary, then
+  ;; summarize the interval-balances and interval-amounts
+  (define work-to-do (length splits))
+  (let loop ((results '())
+             (interval-bals '())
+             (interval-amts '())
+             (splits splits)
+             (work-done 0)
+             (daily-balances (cdr balances))
+             (daily-dates (cdr daily-dates))
+             (interval-start (car interval-dates))
+             (interval-dates (cdr interval-dates)))
 
-      (let ((minmax-accum (gnc:make-stats-collector))
-            (stats-accum (gnc:make-stats-collector))
-            (gain-loss-accum (gnc:make-drcr-collector))
-            (last-balance start-balance)
-            (last-balance-time from))
-        
-        
-        (define (update-stats  split-amt split-time)
-          (let ((time-difference (- split-time
-                                    last-balance-time)))
-            (stats-accum 'add (* last-balance time-difference))
-            (set! last-balance (+ last-balance split-amt))
-            (set! last-balance-time split-time)
-            (minmax-accum 'add last-balance)
-            (gain-loss-accum 'add split-amt)))
+    (cond
+     ;; daily-dates finished. job done. add details for last-interval
+     ;; which must be handled separately, and return to caller
+     ((null? daily-dates)
+      (reverse
+       (cons (list
+              (qof-print-date interval-start)
+              (qof-print-date (car interval-dates))
+              (/ (apply + interval-bals)
+                 (length interval-bals))
+              (apply max interval-bals)
+              (apply min interval-bals)
+              (apply + (filter positive? interval-amts))
+              (- (apply + (filter negative? interval-amts)))
+              (apply + interval-amts))
+             results)))
 
-        (define (split-recurse)
-          (if (or (null? splits)
-                  (> (xaccTransGetDate (xaccSplitGetParent (car splits)))
-                     to))
-              #f
-              (let* 
-                  ((split (car splits))
-                   (split-time (xaccTransGetDate (xaccSplitGetParent split)))
-                   ;; FIXME: Which date should we use here? The 'to'
-                   ;; date? the 'split-time'?
-		   (split-amt (get-split-value split split-time))
-		   (next (cdr splits)))
-		
-		(if 
-		 ;; Check whether this split and next one are a pair
-		 ;; from the same transaction, and the only ones in
-		 ;; this transaction.
-		 ;; If they are and the flag is set appropriately,
-		 ;; then skip both.
-		 (or internal
-		     (null? next)
-		     (let* ((next-split (car next))
-			    (trans (xaccSplitGetParent split))
-			    (next-trans (xaccSplitGetParent next-split))
-			    (count (xaccTransCountSplits trans)))
-		       (not (and (eqv? count 2)
-				 (equal? trans next-trans)))))                
-		 (begin
-		  (gnc:debug "split " split)
-		  (gnc:debug "split-time " split-time)
-		  (gnc:debug "split-amt " split-amt)
-		  ;; gnc:debug converts its input to a string before
-		  ;; deciding whether to print it, and converting
-		  ;; |splits| to a string is O(N) in its length.  Since
-		  ;; this code runs for every split, leaving that
-		  ;; gnc:debug in makes the whole thing O(N^2) in number
-		  ;; of splits.  If someone really needs this output,
-		  ;; they should uncomment the gnc:debug call.
-					; (gnc:debug "splits " splits)
-		  (update-stats split-amt split-time)
-		  (set! splits next)
-		  (split-recurse))
-		 (begin
-		  (set! splits (cdr next))
-		  (split-recurse))))))
+     ;; first daily-date > first interval-date -- crossed interval
+     ;; boundary -- add interval details to results
+     ((> (car daily-dates) (car interval-dates))
+      (gnc:report-percent-done (* 100 (/ work-done work-to-do)))
+      (loop (cons (list
+                   (qof-print-date interval-start)
+                   (qof-print-date (decdate (car interval-dates)
+                                            DayDelta))
+                   (/ (apply + interval-bals)
+                      (length interval-bals))
+                   (apply max interval-bals)
+                   (apply min interval-bals)
+                   (apply + (filter positive? interval-amts))
+                   (- (apply + (filter negative? interval-amts)))
+                   (apply + interval-amts))
+                  results)    ;process interval amts&bals
+            '()               ;reset interval-bals
+            '()               ;and interval-amts
+            splits
+            work-done
+            daily-balances
+            daily-dates
+            (car interval-dates)
+            (cdr interval-dates)))
 
-                                        ;  the minmax accumulator
+     ;; we're still within interval, no more splits left within
+     ;; current interval. add daily balance to interval.
+     ((or (null? splits)
+          (> (xaccTransGetDate (xaccSplitGetParent (car splits)))
+             (car interval-dates)))
+      (loop results
+            (cons (car daily-balances) interval-bals)
+            interval-amts
+            splits
+            work-done
+            (cdr daily-balances)
+            (cdr daily-dates)
+            interval-start
+            interval-dates))
 
-        (minmax-accum 'add start-balance)
-
-        (if (not (null? splits))
-            (split-recurse))
-
-        ;; insert a null transaction at the end of the interval
-        (update-stats 0.0 to)
-        (list minmax-accum stats-accum gain-loss-accum last-balance splits)))
-    
-    
-    (for-each
-     (lambda (interval)
-       (let* 
-           
-           ((interval-results 
-             (process-interval 
-              splits 
-              (car interval) 
-              (cadr interval)
-              start-bal-double))
-            (min-max-accum (car interval-results))
-            (stats-accum (cadr interval-results))
-            (gain-loss-accum (caddr interval-results))
-            (last-bal (cadddr interval-results))
-            (rest-splits (list-ref interval-results 4)))
-
-         (set! start-bal-double last-bal)
-         (set! splits rest-splits)
-         (output-row (car interval) 
-                     (cadr interval) 
-                     stats-accum 
-                     min-max-accum gain-loss-accum)))
-     interval-list)
-    
-    
-    (reverse data-rows)))
+     ;; we're still within interval. 'internal' is disallowed; there
+     ;; are at least 2 splits remaining, both from the same
+     ;; transaction. skip them. NOTE we should really expand this
+     ;; conditional whereby all splits are internal, however the
+     ;; option is labelled as 2-splits only. best maintain behaviour.
+     ((and (not internal-included)
+           (pair? (cdr splits))
+           (= 2 (xaccTransCountSplits (xaccSplitGetParent (car splits))))
+           (equal? (xaccSplitGetParent (car splits))
+                   (xaccSplitGetParent (cadr splits))))
+      (loop results
+            interval-bals
+            interval-amts ;interval-amts unchanged
+            (cddr splits) ;skip two splits.
+            (+ 2 work-done)
+            daily-balances
+            daily-dates
+            interval-start
+            interval-dates))
 
+     ;; we're still within interval. there are splits remaining. add
+     ;; split details to interval-amts
+     (else
+      (loop results
+            interval-bals
+            (cons (gnc:gnc-monetary-amount
+                   (exchange-fn
+                    (gnc:make-gnc-monetary
+                     (xaccAccountGetCommodity
+                      (xaccSplitGetAccount (car splits)))
+                     (xaccSplitGetAmount (car splits)))
+                    report-currency
+                    (car interval-dates)))
+                  interval-amts) ;add split amt to list
+            (cdr splits)         ;and loop to next split
+            (1+ work-done)
+            daily-balances
+            daily-dates
+            interval-start
+            interval-dates)))))
 
   ;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Renderer
@@ -326,7 +283,8 @@
          (enddate (gnc:time64-end-day-time 
                    (gnc:date-option-absolute-time 
                     (get-option gnc:pagename-general optname-to-date))))
-         (stepsize (gnc:deltasym-to-delta (get-option gnc:pagename-general optname-stepsize)))
+         (stepsize (gnc:deltasym-to-delta
+                    (get-option gnc:pagename-general optname-stepsize)))
          (report-currency (get-option gnc:pagename-general 
                                       optname-report-currency))
          (price-source (get-option gnc:pagename-general
@@ -335,7 +293,9 @@
          (internal-included (not (get-option gnc:pagename-accounts optname-internal)))
          (accounts   (get-option gnc:pagename-accounts (N_ "Accounts")))
          (dosubs?    (get-option gnc:pagename-accounts optname-subacct))
-
+         (accounts (if dosubs?
+                       (gnc:accounts-and-all-descendants accounts)
+                       accounts))
          (plot-type  (get-option gnc:pagename-display (N_ "Plot Type")))
          (show-plot? (get-option gnc:pagename-display (N_ "Show plot")))
          (show-table? (get-option gnc:pagename-display (N_ "Show table")))
@@ -344,30 +304,12 @@
 
 	 (commodity-list #f)
 	 (exchange-fn #f)
+         (all-zeros? #t))
 
-         (beforebegindate (gnc:time64-end-day-time 
-                           (gnc:time64-previous-day begindate)))
-         (all-zeros? #t)
-         ;; startbal will be a commodity-collector
-         (startbal  '()))
-
-    (define (list-all-zeros? alist)
-      (if (null? alist) #t
-          (if (not (= 0.0 (car alist)))
-              #f
-              (list-all-zeros? (cdr alist)))))
-    
-    (define (monetary->double foreign-monetary date)
-      (gnc-numeric-to-double
-       (gnc:gnc-monetary-amount
-        (exchange-fn foreign-monetary report-currency date))))
-
-    (gnc:html-document-set-title! document report-title)
     ;;(warn commodity-list)
 
     (if (not (null? accounts))
         (let ((query (qof-query-create-for-splits))
-              (splits '())
               (data '()))
 
           ;; The percentage done numbers here are a hack so that
@@ -378,11 +320,9 @@
           ;; lookup should be distributed and done when actually
           ;; needed so as to amortize the cpu time properly.
 	  (gnc:report-percent-done 1)
-	  (set! commodity-list (gnc:accounts-get-commodities 
-                                (append 
-                                 (gnc:acccounts-get-all-subaccounts accounts)
-                                 accounts)
-                                report-currency))
+	  (set! commodity-list (gnc:accounts-get-commodities
+                                accounts report-currency))
+
 	  (gnc:report-percent-done 5)
 	  (set! exchange-fn (gnc:case-exchange-time-fn 
                              price-source report-currency 
@@ -400,22 +340,6 @@
           ;; add accounts to the query (include subaccounts 
           ;; if requested)
 	  (gnc:report-percent-done 25)
-          (if dosubs? 
-              (let ((subaccts '()))
-                (for-each 
-                 (lambda (acct)
-                   (let ((this-acct-subs 
-                          (gnc-account-get-descendants-sorted acct)))
-                     (if (list? this-acct-subs)
-                         (set! subaccts 
-                               (append subaccts this-acct-subs)))))
-                 accounts)
-                ;; Beware: delete-duplicates is an O(n^2)
-                ;; algorithm. More efficient method: sort the list,
-                ;; then use a linear algorithm.
-                (set! accounts
-                      (delete-duplicates (append accounts subaccts)))))
-	  (gnc:report-percent-done 30)
 
           (xaccQueryAddAccountMatch query accounts QOF-GUID-MATCH-ANY QOF-QUERY-AND)
           
@@ -427,35 +351,46 @@
 				    (list QUERY-DEFAULT-SORT)
 				    '())
           
-          ;; get the query results 
-          (set! splits (qof-query-run query))
 	  (gnc:report-percent-done 40)
-          
-          ;; find the net starting balance for the set of accounts 
-          (set! startbal 
-                (gnc:accounts-get-balance-helper 
-                 accounts 
-                 (lambda (acct) (gnc:account-get-comm-balance-at-date 
-                                 acct beforebegindate #f))
-                 (lambda (x) #f)))
-	  (gnc:report-percent-done 50)
 
-          (set! startbal 
-                (gnc-numeric-to-double
-                 (gnc:gnc-monetary-amount
-                  (gnc:sum-collector-commodity 
-                   startbal
-                   report-currency 
-                   (lambda (a b) 
-                     (exchange-fn a b beforebegindate))))))
-	  (gnc:report-percent-done 60)
-	  
-          ;; and analyze the data 
-          (set! data (analyze-splits splits startbal
-                                     begindate enddate 
-                                     stepsize monetary->double
-				     internal-included))
-	  (gnc:report-percent-done 70)
+          (let* ((splits (qof-query-run query))
+                 (daily-dates (gnc:make-date-list begindate enddate DayDelta))
+                 (interval-dates (gnc:make-date-list begindate enddate stepsize))
+
+                 ;; for accounts-balances generation
+                 (work-to-do (length accounts))
+                 (accounts-balances (map
+                                     (lambda (work-done acc)
+                                       (gnc:report-percent-done
+                                        (* 100 (/ work-done work-to-do)))
+                                       (gnc:account-get-balances-at-dates
+                                        acc daily-dates))
+                                     (iota work-to-do)
+                                     accounts))
+
+                 ;; for daily-balances generation
+                 (work-to-do (length daily-dates))
+                 (balances (map
+                            (lambda (work-done date accounts-balance)
+                              (gnc:report-percent-done (* 100 (/ work-done work-to-do)))
+                              (gnc:gnc-monetary-amount
+                               (gnc:sum-collector-commodity
+                                (apply gnc:monetaries-add accounts-balance)
+                                report-currency
+                                (lambda (monetary target-curr)
+                                  (exchange-fn monetary target-curr date)))))
+                            (iota work-to-do)
+                            daily-dates
+                            (apply zip accounts-balances))))
+
+            (qof-query-destroy query)
+
+            (unless (null? splits)
+              (set! data
+                (analyze-splits splits balances daily-dates interval-dates
+                                internal-included exchange-fn report-currency))))
+
+          (gnc:report-percent-done 70)
           
           ;; make a plot (optionally)... if both plot and table, 
           ;; plot comes first. 
@@ -470,7 +405,7 @@
                         ((number-data
                           (map 
                            (lambda (row) (list-ref row 2)) data)))
-                      (if (not (list-all-zeros? number-data))
+                      (if (not (every zero? number-data))
                           (begin
                             (gnc:html-barchart-append-column! 
                              barchart
@@ -486,7 +421,7 @@
                 (if (memq 'GainPlot plot-type)
                     (let ((number-data 
                            (map (lambda (row) (list-ref row 7)) data)))
-                      (if (not (list-all-zeros? number-data))
+                      (if (not (every zero? number-data))
                           (begin
                             (gnc:html-barchart-append-column! 
                              barchart
@@ -505,8 +440,8 @@
                            (map (lambda (row) (list-ref row 6)) data)))
                       ;; debit column 
                       (if (not (and
-                                (list-all-zeros? debit-data)
-                                (list-all-zeros? credit-data)))
+                                (every zero? debit-data)
+                                (every zero? credit-data)))
                           (begin
                             (gnc:html-barchart-append-column! 
                              barchart
@@ -530,6 +465,7 @@
                 
                 (if (not all-zeros?)
                     (begin
+                      (gnc:html-barchart-set-title! barchart report-title)
                       (gnc:html-barchart-set-col-labels! 
                        barchart col-labels)
                       (gnc:html-barchart-set-col-colors!
@@ -550,7 +486,8 @@
           ;; make a table (optionally)
 	  (gnc:report-percent-done 80)
           (if show-table? 
-              (let ((table (gnc:make-html-table)))
+              (let ((table (gnc:make-html-table))
+                    (scu (gnc-commodity-get-fraction report-currency)))
                 (gnc:html-table-set-col-headers!
                  table columns)
                 (for-each
@@ -562,7 +499,14 @@
                      (list "date-cell" "date-cell"
                            "number-cell" "number-cell" "number-cell"
                            "number-cell" "number-cell" "number-cell")
-                     row)))
+                     (cons* (car row)
+                            (cadr row)
+                            (map
+                             (lambda (amt)
+                               (gnc:make-gnc-monetary
+                                report-currency
+                                (gnc-numeric-convert amt scu GNC-RND-ROUND)))
+                             (cddr row))))))
                  data)
                 (gnc:html-document-add-object! document table))))
 
