@@ -341,12 +341,6 @@ developing over time"))
                   c report-currency
                   (lambda (a b) (exchange-fn a b date)))))))
 
-          (define (collector-minus a b)
-            (let ((coll (gnc:make-commodity-collector)))
-              (coll 'merge a #f)
-              (coll 'minusmerge b #f)
-              coll))
-
           ;; copy of gnc:not-all-zeros using gnc-monetary
           (define (not-all-zeros data)
             (cond ((gnc:gnc-monetary? data) (not (zero? (gnc:gnc-monetary-amount data))))
@@ -361,13 +355,22 @@ developing over time"))
           (define account-balances-alist
             (map
              (lambda (acc)
-               (cons acc
-                     (map
-                      (if (reverse-balance? acc) gnc:monetary-neg identity)
-                      (gnc:account-get-balances-at-dates
-                       acc dates-list
-                       #:ignore-closing? (gnc:account-is-inc-exp? acc)))))
-             accounts))
+               (let* ((comm (xaccAccountGetCommodity acc))
+                      (split->elt (if (reverse-balance? acc)
+                                      (lambda (s)
+                                        (gnc:make-gnc-monetary
+                                         comm (- (xaccSplitGetNoclosingBalance s))))
+                                      (lambda (s)
+                                        (gnc:make-gnc-monetary
+                                         comm (xaccSplitGetNoclosingBalance s))))))
+                 (cons acc
+                       (gnc:account-accumulate-at-dates
+                        acc dates-list
+                        #:split->elt split->elt
+                        #:nosplit->elt (gnc:make-gnc-monetary comm 0)))))
+             ;; all selected accounts (of report-specific type), *and*
+             ;; their descendants (of any type) need to be scanned.
+             (gnc:accounts-and-all-descendants accounts)))
 
           ;; Creates the <balance-list> to be used in the function
           ;; below.
@@ -393,8 +396,8 @@ developing over time"))
                           (cdr dates-list)
                           (cons (if do-intervals?
                                     (collector->monetary
-                                     (collector-minus (cadr list-of-mon-collectors)
-                                                      (car list-of-mon-collectors))
+                                     (gnc:collector- (cadr list-of-mon-collectors)
+                                                     (car list-of-mon-collectors))
                                      (cadr dates-list))
                                     (collector->monetary
                                      (car list-of-mon-collectors)
@@ -463,9 +466,7 @@ developing over time"))
           ;; needed so as to amortize the cpu time properly.
           (gnc:report-percent-done 1)
           (set! commodity-list (gnc:accounts-get-commodities
-                                (append
-                                 (gnc:acccounts-get-all-subaccounts accounts)
-                                 accounts)
+                                (gnc:accounts-and-all-descendants accounts)
                                 report-currency))
           (set! exchange-fn (gnc:case-exchange-time-fn
                              price-source report-currency
@@ -705,18 +706,22 @@ developing over time"))
              (gnc:report-percent-done 98)
              (gnc:html-document-add-object! document chart)
              (if show-table?
-                 (begin
+                 (let ((scu (gnc-commodity-get-fraction report-currency)))
                    (gnc:html-table-append-column! table date-string-list)
 
-                   (letrec
-                       ((addcol
-                         (lambda (col)
-                           (if (not (null? col))
-                               (begin
-                                 (gnc:html-table-append-column!
-                                  table (car col))
-                                 (addcol (cdr col)))))))
-                     (addcol (map cadr all-data)))
+                   (for-each
+                    (lambda (col)
+                      (gnc:html-table-append-column!
+                       table
+                       (map
+                        (lambda (mon)
+                          (gnc:make-gnc-monetary
+                           report-currency
+                           (gnc-numeric-convert
+                            (gnc:gnc-monetary-amount mon)
+                            scu GNC-HOW-RND-ROUND)))
+                        col)))
+                    (map cadr all-data))
 
                    (gnc:html-table-set-col-headers!
                     table
