@@ -24,8 +24,6 @@
 (use-modules (gnucash core-utils)
              (gnucash gettext))
 
-(define gnc:reldate-list '())
-
 ;; get stuff from localtime date vector
 (define (gnc:date-get-year datevec)
   (+ 1900 (tm:year datevec)))
@@ -68,7 +66,7 @@
   (gnc:date-get-year-day (gnc-localtime t64)))
 
 (define (gnc:date-get-year-string datevec)
-  (gnc-locale-to-utf8 (strftime "%Y" datevec)))
+  (gnc-print-time64 (gnc-mktime datevec) "%Y"))
 
 (define (gnc:date-get-quarter-string datevec)
   (format #f "Q~d" (gnc:date-get-quarter datevec)))
@@ -80,17 +78,15 @@
    (gnc:date-get-year-string datevec)))
 
 (define (gnc:date-get-month-string datevec)
-  (gnc-locale-to-utf8 (strftime "%B" datevec)))
+  (gnc-print-time64 (gnc-mktime datevec) "%B"))
 
 (define (gnc:date-get-month-year-string datevec)
-  (gnc-locale-to-utf8 (strftime "%B %Y" datevec)))
+  (gnc-print-time64 (gnc-mktime datevec) "%B %Y"))
 
 (define (gnc:date-get-week-year-string datevec)
-  (let* ((beginweekt64 (* (gnc:time64-get-week
-                            (gnc-mktime datevec))
-                          604800))
-         (begin-string (qof-print-date (+ beginweekt64 345600)))
-         (end-string (qof-print-date (+ beginweekt64 864000))))
+  (let* ((beginweekt64 (* (gnc:time64-get-week (gnc-mktime datevec)) 7 86400))
+         (begin-string (qof-print-date (+ beginweekt64 (* 3 86400))))
+         (end-string (qof-print-date (+ beginweekt64 (* 9 86400)))))
     (format #f (_ "~a to ~a") begin-string end-string)))
 
 ;; is leap year?
@@ -153,22 +149,26 @@
   (let ((lt (gnc-localtime caltime)))
     (+ (* 12 (- (gnc:date-get-year lt) 1970.0))
        (gnc:date-get-month lt) -1
-       (/ (- (gnc:date-get-month-day lt) 1.0) (gnc:days-in-month 
-					       (gnc:date-get-month lt)
-					       (gnc:date-get-year lt))))))
+       (/ (- (gnc:date-get-month-day lt) 1.0)
+          (gnc:days-in-month
+	   (gnc:date-get-month lt)
+	   (gnc:date-get-year lt))))))
 
-;; convert a date in seconds since 1970 into # of two-week periods since
-;; Jan 4, 1970 ignoring leap-seconds (just halfing date-to-week-fraction)
 (define (gnc:date-to-twoweek-fraction caltime)
   (/ (gnc:date-to-week-fraction caltime) 2))
 
-;; convert a date in seconds since 1970 into # of weeks since Jan 4, 1970
-;; ignoring leap-seconds
+;; which dow does the week start? 1=Sunday, 2=Monday etc
+(define weekstart
+  (let ((dow (gnc-start-of-week)))
+    (cond
+     ((zero? dow) (gnc:warn "cannot determine start of week. using Sunday") 1)
+     (else dow))))
+
 (define (gnc:date-to-week-fraction caltime)
-  (/ (- (/ (/ caltime 3600.0) 24) 3) 7))
+  (/ (- (/ caltime 86400) 1 weekstart) 7))
 
 (define (gnc:date-to-week caltime)
-  (floor (/ (- (/ caltime 86400) 3) 7)))
+  (floor (gnc:date-to-week-fraction caltime)))
 
 ;; convert a date in seconds since 1970 into # of days since Feb 28, 1970
 ;; ignoring leap-seconds
@@ -209,38 +209,92 @@
 ;; date-granularity comparison functions.
 
 (define (gnc:time64-le-date t1 t2)
+  (issue-deprecation-warning "gnc:time64-le-date is unused")
   (<= (time64CanonicalDayTime t1)
       (time64CanonicalDayTime t2)))
 
 (define (gnc:time64-ge-date t1 t2)
+  (issue-deprecation-warning "gnc:time64-ge-date is unused")
   (gnc:time64-le-date t2 t1))
 
-;; Build a list of time intervals. 
+;; returns #t if adding 1 to mday causes a month change.
+(define (end-month? date)
+  (let ((nextdate (gnc-localtime date)))
+    (set-tm:mday nextdate (1+ (tm:mday nextdate)))
+    (not (= (tm:mon (gnc-localtime (gnc-mktime nextdate)))
+            (tm:mon (gnc-localtime date))))))
+
+(define (incdate-months date nmonths)
+  (let* ((new-date (gnc-localtime date))
+         (newmonth (+ (tm:mon new-date) nmonths))
+         (new-month-proper (floor-remainder newmonth 12))
+         (new-year-proper (+ (tm:year new-date) (floor-quotient newmonth 12))))
+    (set-tm:year new-date new-year-proper)
+    (set-tm:mon new-date new-month-proper)
+    (let loop ((new-mday (tm:mday new-date)))
+      (set-tm:mday new-date new-mday)
+      (let ((res (gnc-mktime new-date)))
+        (cond
+         ;; next date causes a date slip. reduce mday.
+         ((not (= new-month-proper (tm:mon (gnc-localtime res))))
+          (loop (1- new-mday)))
+         ;; orig date is month-end. ensure all dates are month-ends.
+         ((and (end-month? date) (not (end-month? res)))
+          (loop (1+ new-mday)))
+         (else res))))))
+
+;; Build a list of time intervals.
 ;;
 ;; Note that the last interval will be shorter than <incr> if
 ;; (<curd>-<endd>) is not an integer multiple of <incr>. If you don't
 ;; want that you'll have to write another function.
-(define (gnc:make-date-interval-list current-date end-date increment)
-  (if (< current-date end-date)
-      (let ((next-date (incdate current-date increment)))
-        (if (< next-date end-date)
-            (cons (list current-date (decdate next-date SecDelta) '())
-                  (gnc:make-date-interval-list next-date end-date increment))
-            (cons (list current-date end-date '())
-                  '())))
-      '()))
-  
+(define (gnc:make-date-interval-list startdate enddate incr)
+  (define month-delta
+    (assv-ref MonthDeltas incr))
+  (define (make-interval from to)
+    (list from (if (< to enddate) (decdate to SecDelta) enddate)))
+  (let loop ((result '())
+             (date startdate)
+             (idx 0))
+    (cond
+     ((>= date enddate)
+      (reverse result))
+     (month-delta
+      (let* ((curr (incdate-months startdate (* month-delta idx)))
+             (next (incdate-months startdate (* month-delta (1+ idx)))))
+        (loop (cons (make-interval curr next) result)
+              next
+              (1+ idx))))
+     (else
+      (let ((next (incdate date incr)))
+        (loop (cons (make-interval date next) result)
+              next
+              (1+ idx)))))))
+
 ;; Build a list of times.  The dates are evenly spaced with the
 ;; stepsize 'incr'. If the difference of 'startdate' and 'enddate' is
 ;; not an integer multiple of 'incr', 'enddate' will be added as the
 ;; last element of the list, thus making the last interval smaller
 ;; than 'incr'.
 (define (gnc:make-date-list startdate enddate incr)
-  (if (< startdate enddate)
-      (cons startdate
-            (gnc:make-date-list (incdate startdate incr)
-                                enddate incr))
-      (list enddate)))
+  (define month-delta
+    (assv-ref MonthDeltas incr))
+  (let loop ((result '())
+             (date startdate)
+             (idx 0))
+    (cond
+     ((>= date enddate)
+      (reverse (cons enddate result)))
+     (month-delta
+      (let* ((curr (incdate-months startdate (* month-delta idx)))
+             (next (incdate-months startdate (* month-delta (1+ idx)))))
+        (loop (cons curr result)
+              next
+              (1+ idx))))
+     (else
+      (loop (cons date result)
+            (incdate date incr)
+            (1+ idx))))))
 
 ; A reference zero date - the Beginning Of The Epoch
 ; Note: use of eval is evil... by making this a generator function, 
@@ -310,6 +364,13 @@
     (set-tm:mday ddt 90)
     ddt))
 
+(define MonthDeltas
+  (list
+   (cons MonthDelta 1)
+   (cons QuarterDelta 3)
+   (cons HalfYearDelta 6)
+   (cons YearDelta 12)))
+
 ;; if you add any more FooDeltas, add to this list!!!
 
 (define deltalist
@@ -355,6 +416,9 @@
 (define (gnc:time64-next-day t64)
   (incdate t64 DayDelta))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; relative-date functions start here
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define (gnc:reldate-get-symbol x) (vector-ref x 0))
 (define (gnc:reldate-get-string x) (vector-ref x 1))
@@ -362,38 +426,56 @@
 (define (gnc:reldate-get-fn x) (vector-ref x 3))
 
 (define (gnc:make-reldate-hash hash reldate-list)
+  (issue-deprecation-warning "gnc:make-reldate-hash is deprecated.")
   (map (lambda (reldate) (hash-set! 
 			  hash 
 			  (gnc:reldate-get-symbol reldate)
 			  reldate))
        reldate-list))
 
-(define gnc:reldate-string-db (gnc:make-string-database))
+;; the following two variables will be inlined and can be deprecated
+(define gnc:reldate-string-db (gnc:make-string-database)) ;deprecate
+(define gnc:relative-date-values '())                     ;deprecate
 
-(define gnc:relative-date-values '())
-
-(define gnc:relative-date-hash (make-hash-table 23))
+;; the globally available hash of reldates (hash-key = reldate
+;; symbols, hash-value = a vector, reldate data). aim to deprecate it
+;; being exported.
+(define gnc:relative-date-hash (make-hash-table))
 
 (define (gnc:get-absolute-from-relative-date date-symbol)
+  ;; used in options.scm
   (let ((rel-date-data (hash-ref gnc:relative-date-hash date-symbol)))
     (if rel-date-data
-       ((gnc:reldate-get-fn rel-date-data))
-       (gnc:error "Tried to look up an undefined date symbol"))))
+        ((gnc:reldate-get-fn rel-date-data))
+        (let* ((msg (_ "Tried to look up an undefined date symbol \
+'~a'. This report was probably saved by a later version of GnuCash. \
+Defaulting to today."))
+               (conmsg (format #f msg date-symbol))
+               (uimsg (format #f (_ msg) date-symbol)))
+          (gnc:gui-warn conmsg uimsg)
+          (current-time)))))
 
 (define (gnc:get-relative-date-strings date-symbol)
+  (issue-deprecation-warning "gnc:get-relative-date-strings is unused.")
   (let ((rel-date-info (hash-ref gnc:relative-date-hash date-symbol)))
     
     (cons (gnc:reldate-get-string rel-date-info)
 	  (gnc:relate-get-desc rel-date-info))))
 
 (define (gnc:get-relative-date-string date-symbol)
+  ;; used in options.scm
   (let ((rel-date-info (hash-ref gnc:relative-date-hash date-symbol)))
     (gnc:reldate-get-string rel-date-info)))
 
 (define (gnc:get-relative-date-desc date-symbol)
+  ;; used in options.scm
   (let ((rel-date-info (hash-ref gnc:relative-date-hash date-symbol)))
     (gnc:reldate-get-desc rel-date-info)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; end relative-date functions
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
 (define (gnc:get-start-cal-year)
   (let ((now (gnc-localtime (current-time))))
     (set-tm:sec now 0)
@@ -743,6 +825,9 @@
 ;;start-cur-fin-year start-prev-fin-year end-prev-fin-year
 
 (define (gnc:reldate-initialize)
+  (define gnc:reldate-string-db (gnc:make-string-database))
+  (define gnc:relative-date-values #f)
+
   (gnc:reldate-string-db 
    'store 'start-cal-year-string 
    (N_ "Start of this year"))
@@ -1066,7 +1151,8 @@
 		 (gnc:reldate-string-db 'lookup 'one-year-ahead-desc)
 		 gnc:get-one-year-ahead)))
 
-
-  (gnc:make-reldate-hash gnc:relative-date-hash gnc:relative-date-values)
-  (set! gnc:reldate-list
-	(map (lambda (x) (vector-ref x 0)) gnc:relative-date-values)))
+  ;; initialise gnc:relative-date-hash
+  (for-each
+   (lambda (reldate)
+     (hash-set! gnc:relative-date-hash (gnc:reldate-get-symbol reldate) reldate))
+   gnc:relative-date-values))
